@@ -1,20 +1,25 @@
-#' Clone the Excerpts Code from Github
+#' Clone the Excerpts Code from \url{github.com}
+#'
+#' Get excerpts' the latest commit to branch master on 
+#' \url{https://github.com/fvafrCU/excerpts/}.
+#' Meant for development only.
 #'
 #' @param directory Where to clone to.
 #' @param force Overwrite the directory?
+#' @param branch See \code{\link[git2r:clone]{git2r::clone}}.
 #' @param remove_dot_git Remove the .git/ from the clone?
-#' @return The status of \code{git2r::clone}, or, if remove_dot_git is
-#' TRUE, the \code{\link{capture.output}} thereof.
+#' @return The status of\code{\link[git2r:clone]{git2r::clone}}, or,
+#' if \code{remove_dot_git} is TRUE, the \code{\link{capture.output}} thereof.
 #' @export
 #' @examples
 #' path <- file.path(tempdir(), "excerpts")
 #' get_excerpts(directory = path, force = TRUE)
 #' \dontrun{print(set_excertps_path(path = path))}
-get_excerpts <- function(directory = get_excerpts_path(),
+get_excerpts <- function(directory = get_excerpts_path(), branch = "devel",
                          force = FALSE, remove_dot_git = TRUE) {
     if (isTRUE(force)) unlink(directory, recursive = TRUE)
     status <- git2r::clone(url = "https://github.com/fvafrCU/excerpts/",
-                           local_path = directory)
+                           branch = branch, local_path = directory)
     if (remove_dot_git) {
         status <- utils::capture.output(status)
         unlink(file.path(directory, ".git/"), recursive = TRUE, force = TRUE)
